# -*- coding: utf-8 -*-
"""
This module simplifies the process of obtaining an authenticated session for steam websites.
After authentication is completed, a :class:`requests.Session` is created containing the auth cookies.
The session can be used to access ``steamcommunity.com``, ``store.steampowered.com``, and ``help.steampowered.com``.

.. warning::
    A web session may expire randomly, or when you login from different IP address.
    Some pages will return status code `401` when that happens.
    Keep in mind if you are trying to write robust code.

.. note::
    If you are using :class:`.SteamClient` take a look at :meth:`.SteamClient.get_web_session()`

.. note::
    If you need to authenticate as a mobile device for things like trading confirmations
    use :class:`MobileWebAuth` instead. The login process is identical, and in addition
    you will get :attr:`.oauth_token`.


Example usage:

.. code:: python

    import steam.webauth as wa

    user = wa.WebAuth('username')

    # At a console, cli_login can be used to easily perform all login steps
    session = user.cli_login('password')
    session.get('https://store.steampowered.com/account/history')

    # Or the login steps be implemented for other situation like so
    try:
        user.login('password')
    except (wa.CaptchaRequired, wa.LoginIncorrect) as exp:
        if isinstance(exp, LoginIncorrect):
            # ask for new password
        else:
            password = self.password

        if isinstance(exp, wa.CaptchaRequired):
            print user.captcha_url
            # ask a human to solve captcha
        else:
            captcha = None

        user.login(password=password, captcha=captcha)
    except wa.EmailCodeRequired:
        user.login(email_code='ZXC123')
    except wa.TwoFactorCodeRequired:
        user.login(twofactor_code='ZXC123')

    user.session.get('https://store.steampowered.com/account/history/')

"""
import json
from time import time
from base64 import b64encode
from getpass import getpass
import six
import requests

from steam.steamid import SteamID
from steam.utils.web import make_requests_session, generate_session_id
from steam.core.crypto import rsa_publickey, pkcs1v15_encrypt

if six.PY2:
    intBase = long
    _cli_input = raw_input
else:
    intBase = int
    _cli_input = input


class WebAuth(object):
    key = None
    logged_on = False    #: whether authentication has been completed successfully
    session = None      #: :class:`requests.Session` (with auth cookies after auth is completed)
    session_id = None   #: :class:`str`, session id string
    captcha_gid = -1
    captcha_code = ''
    steam_id = None     #: :class:`.SteamID` (after auth is completed)

    def __init__(self, username, password=''):
        self.__dict__.update(locals())
        self.session = make_requests_session()
        self._session_setup()

    def _session_setup(self):
        pass

    @property
    def captcha_url(self):
        """If a captch is required this property will return url to the image, or ``None``"""
        if self.captcha_gid == -1:
            return None
        else:
            return "https://steamcommunity.com/login/rendercaptcha/?gid=%s" % self.captcha_gid

    def get_rsa_key(self, username):
        """Get rsa key for a given username

        :param username: username
        :type  username: :class:`str`
        :return: json response
        :rtype: :class:`dict`
        :raises HTTPError: any problem with http request, timeouts, 5xx, 4xx etc
        """
        try:
            resp = self.session.post('https://steamcommunity.com/login/getrsakey/',
                                     timeout=15,
                                     data={
                                         'username': username,
                                         'donotcache': int(time() * 1000),
                                         },
                                     ).json()
        except requests.exceptions.RequestException as e:
            raise HTTPError(str(e))

        return resp

    def _load_key(self):
        if not self.key:
            resp = self.get_rsa_key(self.username)

            self.key = rsa_publickey(intBase(resp['publickey_mod'], 16),
                                     intBase(resp['publickey_exp'], 16),
                                     )
            self.timestamp = resp['timestamp']

    def _send_login(self, password='', captcha='', email_code='', twofactor_code=''):
        data = {
            'username': self.username,
            "password": b64encode(pkcs1v15_encrypt(self.key, password.encode('ascii'))),
            "emailauth": email_code,
            "emailsteamid": str(self.steam_id) if email_code else '',
            "twofactorcode": twofactor_code,
            "captchagid": self.captcha_gid,
            "captcha_text": captcha,
            "loginfriendlyname": "python-steam webauth",
            "rsatimestamp": self.timestamp,
            "remember_login": 'true',
            "donotcache": int(time() * 100000),
        }

        try:
            return self.session.post('https://steamcommunity.com/login/dologin/', data=data, timeout=15).json()
        except requests.exceptions.RequestException as e:
            raise HTTPError(str(e))

    def _finalize_login(self, login_response):
        self.steam_id = SteamID(login_response['transfer_parameters']['steamid'])

    def login(self, password='', captcha='', email_code='', twofactor_code='', language='english'):
        """Attempts web login and returns on a session with cookies set

        :param password: password, if it wasn't provided on instance init
        :type  password: :class:`str`
        :param captcha: text reponse for captcha challenge
        :type  captcha: :class:`str`
        :param email_code: email code for steam guard
        :type  email_code: :class:`str`
        :param twofactor_code: 2FA code for steam guard
        :type  twofactor_code: :class:`str`
        :param language: select language for steam web pages (sets language cookie)
        :type  language: :class:`str`
        :return: a session on success and :class:`None` otherwise
        :rtype: :class:`requests.Session`, :class:`None`
        :raises HTTPError: any problem with http request, timeouts, 5xx, 4xx etc
        :raises LoginIncorrect: wrong username or password
        :raises CaptchaRequired: when captcha is needed
        :raises CaptchaRequiredLoginIncorrect: when captcha is needed and login is incorrect
        :raises EmailCodeRequired: when email is needed
        :raises TwoFactorCodeRequired: when 2FA is needed
        """
        if self.logged_on:
            return self.session

        if password:
            self.password = password
        elif self.password:
            password = self.password
        else:
            raise LoginIncorrect("password is not specified")

        if not captcha and self.captcha_code:
            captcha = self.captcha_code

        self._load_key()
        resp = self._send_login(password=password, captcha=captcha, email_code=email_code, twofactor_code=twofactor_code)

        if resp['success'] and resp['login_complete']:
            self.logged_on = True
            self.password = self.captcha_code = ''
            self.captcha_gid = -1

            for cookie in list(self.session.cookies):
                for domain in ['store.steampowered.com', 'help.steampowered.com', 'steamcommunity.com']:
                    self.session.cookies.set(cookie.name, cookie.value, domain=domain, secure=cookie.secure)

            self.session_id = generate_session_id()

            for domain in ['store.steampowered.com', 'help.steampowered.com', 'steamcommunity.com']:
                self.session.cookies.set('Steam_Language', language, domain=domain)
                self.session.cookies.set('birthtime', '-3333', domain=domain)
                self.session.cookies.set('sessionid', self.session_id, domain=domain)

            self._finalize_login(resp)

            return self.session
        else:
            if resp.get('captcha_needed', False):
                self.captcha_gid = resp['captcha_gid']
                self.captcha_code = ''

                if resp.get('clear_password_field', False):
                    self.password = ''
                    raise CaptchaRequiredLoginIncorrect(resp['message'])
                else:
                    raise CaptchaRequired(resp['message'])
            elif resp.get('emailauth_needed', False):
                self.steam_id = SteamID(resp['emailsteamid'])
                raise EmailCodeRequired(resp['message'])
            elif resp.get('requires_twofactor', False):
                raise TwoFactorCodeRequired(resp['message'])
            elif 'too many login failures' in resp.get('message', ''):
                raise TooManyLoginFailures(resp['message'])
            else:
                self.password = ''
                raise LoginIncorrect(resp['message'])

    def cli_login(self, password='', captcha='', email_code='', twofactor_code='', language='english'):
        """Generates CLI prompts to perform the entire login process

        :param password: password, if it wasn't provided on instance init
        :type  password: :class:`str`
        :param captcha: text reponse for captcha challenge
        :type  captcha: :class:`str`
        :param email_code: email code for steam guard
        :type  email_code: :class:`str`
        :param twofactor_code: 2FA code for steam guard
        :type  twofactor_code: :class:`str`
        :param language: select language for steam web pages (sets language cookie)
        :type  language: :class:`str`
        :return: a session on success and :class:`None` otherwise
        :rtype: :class:`requests.Session`, :class:`None`

        .. code:: python

            In [3]: user.cli_login()
            Enter password for 'steamuser':
            Solve CAPTCHA at https://steamcommunity.com/login/rendercaptcha/?gid=1111111111111111111
            CAPTCHA code: 123456
            Invalid password for 'steamuser'. Enter password:
            Solve CAPTCHA at https://steamcommunity.com/login/rendercaptcha/?gid=2222222222222222222
            CAPTCHA code: abcdef
            Enter 2FA code: AB123
            Out[3]: <requests.sessions.Session at 0x6fffe56bef0>

        """

        # loop until successful login
        while True:
            try:
                return self.login(password, captcha, email_code, twofactor_code, language)
            except (LoginIncorrect, CaptchaRequired) as exp:
                email_code = twofactor_code = ''

                if isinstance(exp, LoginIncorrect):
                    prompt = ("Enter password for %s: " if not password else
                              "Invalid password for %s. Enter password: ")
                    password = getpass(prompt % repr(self.username))
                if isinstance(exp, CaptchaRequired):
                    prompt = "Solve CAPTCHA at %s\nCAPTCHA code: " % self.captcha_url
                    captcha = _cli_input(prompt)
                else:
                    captcha = ''
            except EmailCodeRequired:
                prompt = ("Enter email code: " if not email_code else
                          "Incorrect code. Enter email code: ")
                email_code, twofactor_code = _cli_input(prompt), ''
            except TwoFactorCodeRequired:
                prompt = ("Enter 2FA code: " if not twofactor_code else
                          "Incorrect code. Enter 2FA code: ")
                email_code, twofactor_code = '', _cli_input(prompt)


class MobileWebAuth(WebAuth):
    """Identical to :class:`WebAuth`, except it authenticates as a mobile device."""
    oauth_token = None  #: holds oauth_token after successful login

    def _send_login(self, password='', captcha='', email_code='', twofactor_code=''):
        data = {
            'username': self.username,
            "password": b64encode(pkcs1v15_encrypt(self.key, password.encode('ascii'))),
            "emailauth": email_code,
            "emailsteamid": str(self.steam_id) if email_code else '',
            "twofactorcode": twofactor_code,
            "captchagid": self.captcha_gid,
            "captcha_text": captcha,
            "loginfriendlyname": "python-steam webauth",
            "rsatimestamp": self.timestamp,
            "remember_login": 'true',
            "donotcache": int(time() * 100000),
            "oauth_client_id": "DE45CD61",
            "oauth_scope": "read_profile write_profile read_client write_client",
        }

        self.session.cookies.set('mobileClientVersion', '0 (2.1.3)')
        self.session.cookies.set('mobileClient', 'android')

        try:
            return self.session.post('https://steamcommunity.com/login/dologin/', data=data, timeout=15).json()
        except requests.exceptions.RequestException as e:
            raise HTTPError(str(e))
        finally:
            self.session.cookies.pop('mobileClientVersion', None)
            self.session.cookies.pop('mobileClient', None)

    def _finalize_login(self, login_response):
        data = json.loads(login_response['oauth'])
        self.steam_id = SteamID(data['steamid'])
        self.oauth_token = data['oauth_token']

    def oauth_login(self, oauth_token='', steam_id='', language='english'):
        """Attempts a mobile authenticator login using an oauth token, which can be obtained from a previously logged-in
        `MobileWebAuth`

        :param oauth_token: oauth token string, if it wasn't provided on instance init
        :type  oauth_token: :class:`str`
        :param steam_id: `SteamID` of the account to log into, if it wasn't provided on instance init
        :type  steam_id: :class:`str` or :class:`SteamID`
        :param language: select language for steam web pages (sets language cookie)
        :type  language: :class:`str`
        :return: a session on success and :class:`None` otherwise
        :rtype: :class:`requests.Session`, :class:`None`
        :raises HTTPError: any problem with http request, timeouts, 5xx, 4xx etc
        :raises LoginIncorrect: Invalid token or SteamID
        """
        if oauth_token:
            self.oauth_token = oauth_token
        elif self.oauth_token:
            oauth_token = self.oauth_token
        else:
            raise LoginIncorrect('token is not specified')

        if steam_id:
            self.steam_id = SteamID(steam_id)
        elif not self.steam_id:
            raise LoginIncorrect('steam_id is not specified')

        steam_id = self.steam_id.as_64

        data = {
            'access_token': oauth_token
        }

        try:
            resp = self.session.post('https://api.steampowered.com/IMobileAuthService/GetWGToken/v0001', data=data)
        except requests.exceptions.RequestException as e:
            raise HTTPError(str(e))

        try:
            resp_data = resp.json()['response']
        except json.decoder.JSONDecodeError as e:
            if 'Please verify your <pre>key=</pre> parameter.' in resp.text:
                raise LoginIncorrect('invalid token')
            else:
                raise e

        self.session_id = generate_session_id()

        for domain in ['store.steampowered.com', 'help.steampowered.com', 'steamcommunity.com']:
            self.session.cookies.set('birthtime', '-3333', domain=domain)
            self.session.cookies.set('sessionid', self.session_id, domain=domain)
            self.session.cookies.set('mobileClientVersion', '0 (2.1.3)', domain=domain)
            self.session.cookies.set('mobileClient', 'android', domain=domain)
            self.session.cookies.set('steamLogin', str(steam_id) + "%7C%7C" + resp_data['token'], domain=domain)
            self.session.cookies.set('steamLoginSecure', str(steam_id) + "%7C%7C" + resp_data['token_secure'],
                                     domain=domain, secure=True)
            self.session.cookies.set('Steam_Language', language, domain=domain)

        self.logged_on = True

        return self.session


class WebAuthException(Exception):
    pass

class HTTPError(WebAuthException):
    pass

class LoginIncorrect(WebAuthException):
    pass

class CaptchaRequired(WebAuthException):
    pass

class CaptchaRequiredLoginIncorrect(CaptchaRequired, LoginIncorrect):
    pass

class EmailCodeRequired(WebAuthException):
    pass

class TwoFactorCodeRequired(WebAuthException):
    pass

class TooManyLoginFailures(WebAuthException):
    pass



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_linkfilter.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esteammessages_linkfilter.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"^\n,CCommunity_GetLinkFilterHashPrefixes_Request\x12\x10\n\x08hit_type\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r\x12\r\n\x05start\x18\x03 \x01(\x04\"F\n-CCommunity_GetLinkFilterHashPrefixes_Response\x12\x15\n\rhash_prefixes\x18\x01 \x03(\r\"X\n&CCommunity_GetLinkFilterHashes_Request\x12\x10\n\x08hit_type\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r\x12\r\n\x05start\x18\x03 \x01(\x04\"9\n\'CCommunity_GetLinkFilterHashes_Response\x12\x0e\n\x06hashes\x18\x01 \x03(\x0c\"?\n+CCommunity_GetLinkFilterListVersion_Request\x12\x10\n\x08hit_type\x18\x01 \x01(\r\"N\n,CCommunity_GetLinkFilterListVersion_Response\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x04\x32\xf4\x02\n\x13\x43ommunityLinkFilter\x12z\n\x19GetLinkFilterHashPrefixes\x12-.CCommunity_GetLinkFilterHashPrefixes_Request\x1a..CCommunity_GetLinkFilterHashPrefixes_Response\x12h\n\x13GetLinkFilterHashes\x12\'.CCommunity_GetLinkFilterHashes_Request\x1a(.CCommunity_GetLinkFilterHashes_Response\x12w\n\x18GetLinkFilterListVersion\x12,.CCommunity_GetLinkFilterListVersion_Request\x1a-.CCommunity_GetLinkFilterListVersion_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_linkfilter_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CCOMMUNITY_GETLINKFILTERHASHPREFIXES_REQUEST._serialized_start=94
  _CCOMMUNITY_GETLINKFILTERHASHPREFIXES_REQUEST._serialized_end=188
  _CCOMMUNITY_GETLINKFILTERHASHPREFIXES_RESPONSE._serialized_start=190
  _CCOMMUNITY_GETLINKFILTERHASHPREFIXES_RESPONSE._serialized_end=260
  _CCOMMUNITY_GETLINKFILTERHASHES_REQUEST._serialized_start=262
  _CCOMMUNITY_GETLINKFILTERHASHES_REQUEST._serialized_end=350
  _CCOMMUNITY_GETLINKFILTERHASHES_RESPONSE._serialized_start=352
  _CCOMMUNITY_GETLINKFILTERHASHES_RESPONSE._serialized_end=409
  _CCOMMUNITY_GETLINKFILTERLISTVERSION_REQUEST._serialized_start=411
  _CCOMMUNITY_GETLINKFILTERLISTVERSION_REQUEST._serialized_end=474
  _CCOMMUNITY_GETLINKFILTERLISTVERSION_RESPONSE._serialized_start=476
  _CCOMMUNITY_GETLINKFILTERLISTVERSION_RESPONSE._serialized_end=554
  _COMMUNITYLINKFILTER._serialized_start=557
  _COMMUNITYLINKFILTER._serialized_end=929
_builder.BuildServices(DESCRIPTOR, 'steammessages_linkfilter_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_parties.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bsteammessages_parties.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"@\n\x1a\x43Parties_JoinParty_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x11\n\tbeacon_id\x18\x02 \x01(\x04\"H\n\x1b\x43Parties_JoinParty_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\x12\x16\n\x0e\x63onnect_string\x18\x02 \x01(\t\"E\n\x17\x43Parties_BeaconLocation\x12\x15\n\rlocation_type\x18\x01 \x01(\r\x12\x13\n\x0blocation_id\x18\x02 \x01(\x04\"\x9d\x01\n\x1d\x43Parties_CreateBeacon_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x16\n\x0enum_open_slots\x18\x02 \x01(\r\x12+\n\tlocations\x18\x03 \x03(\x0b\x32\x18.CParties_BeaconLocation\x12\x16\n\x0e\x63onnect_string\x18\x04 \x01(\t\x12\x10\n\x08metadata\x18\x05 \x01(\t\"3\n\x1e\x43Parties_CreateBeacon_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\"R\n\'CParties_OnReservationCompleted_Request\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\"=\n(CParties_OnReservationCompleted_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\"M\n\"CParties_CancelReservation_Request\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\"8\n#CParties_CancelReservation_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\"P\n#CParties_ChangeNumOpenSlots_Request\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\x12\x16\n\x0enum_open_slots\x18\x02 \x01(\r\"9\n$CParties_ChangeNumOpenSlots_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\"3\n\x1e\x43Parties_DestroyBeacon_Request\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\"4\n\x1f\x43Parties_DestroyBeacon_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\x32\xa8\x04\n\x07Parties\x12\x46\n\tJoinParty\x12\x1b.CParties_JoinParty_Request\x1a\x1c.CParties_JoinParty_Response\x12O\n\x0c\x43reateBeacon\x12\x1e.CParties_CreateBeacon_Request\x1a\x1f.CParties_CreateBeacon_Response\x12m\n\x16OnReservationCompleted\x12(.CParties_OnReservationCompleted_Request\x1a).CParties_OnReservationCompleted_Response\x12^\n\x11\x43\x61ncelReservation\x12#.CParties_CancelReservation_Request\x1a$.CParties_CancelReservation_Response\x12\x61\n\x12\x43hangeNumOpenSlots\x12$.CParties_ChangeNumOpenSlots_Request\x1a%.CParties_ChangeNumOpenSlots_Response\x12R\n\rDestroyBeacon\x12\x1f.CParties_DestroyBeacon_Request\x1a .CParties_DestroyBeacon_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_parties_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CPARTIES_JOINPARTY_REQUEST._serialized_start=91
  _CPARTIES_JOINPARTY_REQUEST._serialized_end=155
  _CPARTIES_JOINPARTY_RESPONSE._serialized_start=157
  _CPARTIES_JOINPARTY_RESPONSE._serialized_end=229
  _CPARTIES_BEACONLOCATION._serialized_start=231
  _CPARTIES_BEACONLOCATION._serialized_end=300
  _CPARTIES_CREATEBEACON_REQUEST._serialized_start=303
  _CPARTIES_CREATEBEACON_REQUEST._serialized_end=460
  _CPARTIES_CREATEBEACON_RESPONSE._serialized_start=462
  _CPARTIES_CREATEBEACON_RESPONSE._serialized_end=513
  _CPARTIES_ONRESERVATIONCOMPLETED_REQUEST._serialized_start=515
  _CPARTIES_ONRESERVATIONCOMPLETED_REQUEST._serialized_end=597
  _CPARTIES_ONRESERVATIONCOMPLETED_RESPONSE._serialized_start=599
  _CPARTIES_ONRESERVATIONCOMPLETED_RESPONSE._serialized_end=660
  _CPARTIES_CANCELRESERVATION_REQUEST._serialized_start=662
  _CPARTIES_CANCELRESERVATION_REQUEST._serialized_end=739
  _CPARTIES_CANCELRESERVATION_RESPONSE._serialized_start=741
  _CPARTIES_CANCELRESERVATION_RESPONSE._serialized_end=797
  _CPARTIES_CHANGENUMOPENSLOTS_REQUEST._serialized_start=799
  _CPARTIES_CHANGENUMOPENSLOTS_REQUEST._serialized_end=879
  _CPARTIES_CHANGENUMOPENSLOTS_RESPONSE._serialized_start=881
  _CPARTIES_CHANGENUMOPENSLOTS_RESPONSE._serialized_end=938
  _CPARTIES_DESTROYBEACON_REQUEST._serialized_start=940
  _CPARTIES_DESTROYBEACON_REQUEST._serialized_end=991
  _CPARTIES_DESTROYBEACON_RESPONSE._serialized_start=993
  _CPARTIES_DESTROYBEACON_RESPONSE._serialized_end=1045
  _PARTIES._serialized_start=1048
  _PARTIES._serialized_end=1600
_builder.BuildServices(DESCRIPTOR, 'steammessages_parties_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_gamenetworkingui.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steamnetworkingsockets_messages_pb2 as steamnetworkingsockets__messages__pb2
import steam.protobufs.steamdatagram_messages_sdr_pb2 as steamdatagram__messages__sdr__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$steammessages_gamenetworkingui.proto\x1a%steamnetworkingsockets_messages.proto\x1a steamdatagram_messages_sdr.proto\"\x1f\n\x1d\x43GameNetworkingUI_GlobalState\"\xcf\x07\n!CGameNetworkingUI_ConnectionState\x12\x16\n\x0e\x63onnection_key\x18\x01 \x01(\t\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x1b\n\x13\x63onnection_id_local\x18\x03 \x01(\x07\x12\x16\n\x0eidentity_local\x18\x04 \x01(\t\x12\x17\n\x0fidentity_remote\x18\x05 \x01(\t\x12\x18\n\x10\x63onnection_state\x18\n \x01(\r\x12\x12\n\nstart_time\x18\x0c \x01(\r\x12\x12\n\nclose_time\x18\r \x01(\r\x12\x14\n\x0c\x63lose_reason\x18\x0e \x01(\r\x12\x15\n\rclose_message\x18\x0f \x01(\t\x12\x18\n\x10status_loc_token\x18\x10 \x01(\t\x12\x16\n\x0etransport_kind\x18\x14 \x01(\r\x12\x16\n\x0esdrpopid_local\x18\x15 \x01(\t\x12\x17\n\x0fsdrpopid_remote\x18\x16 \x01(\t\x12\x16\n\x0e\x61\x64\x64ress_remote\x18\x17 \x01(\t\x12\x38\n\x0bp2p_routing\x18\x18 \x01(\x0b\x32#.CMsgSteamDatagramP2PRoutingSummary\x12\x15\n\rping_interior\x18\x19 \x01(\r\x12\x19\n\x11ping_remote_front\x18\x1a \x01(\r\x12#\n\x1bping_default_internet_route\x18\x1b \x01(\r\x12>\n\x11\x65\x32\x65_quality_local\x18\x1e \x01(\x0b\x32#.CMsgSteamDatagramConnectionQuality\x12?\n\x12\x65\x32\x65_quality_remote\x18\x1f \x01(\x0b\x32#.CMsgSteamDatagramConnectionQuality\x12-\n%e2e_quality_remote_instantaneous_time\x18  \x01(\x04\x12(\n e2e_quality_remote_lifetime_time\x18! \x01(\x04\x12@\n\x13\x66ront_quality_local\x18( \x01(\x0b\x32#.CMsgSteamDatagramConnectionQuality\x12\x41\n\x14\x66ront_quality_remote\x18) \x01(\x0b\x32#.CMsgSteamDatagramConnectionQuality\x12/\n\'front_quality_remote_instantaneous_time\x18* \x01(\x04\x12*\n\"front_quality_remote_lifetime_time\x18+ \x01(\x04\"Y\n\x19\x43GameNetworkingUI_Message\x12<\n\x10\x63onnection_state\x18\x01 \x03(\x0b\x32\".CGameNetworkingUI_ConnectionState\"\xe6\x01\n#CGameNetworkingUI_ConnectionSummary\x12\x16\n\x0etransport_kind\x18\x01 \x01(\r\x12\x18\n\x10\x63onnection_state\x18\x08 \x01(\r\x12\x14\n\x0csdrpop_local\x18\x02 \x01(\t\x12\x15\n\rsdrpop_remote\x18\x03 \x01(\t\x12\x0f\n\x07ping_ms\x18\x04 \x01(\r\x12\x13\n\x0bpacket_loss\x18\x05 \x01(\x02\x12#\n\x1bping_default_internet_route\x18\x06 \x01(\r\x12\x15\n\rip_was_shared\x18\x07 \x01(\x08\"\xca\x01\n\x1c\x43GameNetworkingUI_AppSummary\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12!\n\x19ip_was_shared_with_friend\x18\n \x01(\x08\x12$\n\x1cip_was_shared_with_nonfriend\x18\x0b \x01(\x08\x12\x1a\n\x12\x61\x63tive_connections\x18\x14 \x01(\r\x12\x36\n\x08main_cxn\x18\x1e \x01(\x0b\x32$.CGameNetworkingUI_ConnectionSummaryB\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_gamenetworkingui_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _CGAMENETWORKINGUI_GLOBALSTATE._serialized_start=113
  _CGAMENETWORKINGUI_GLOBALSTATE._serialized_end=144
  _CGAMENETWORKINGUI_CONNECTIONSTATE._serialized_start=147
  _CGAMENETWORKINGUI_CONNECTIONSTATE._serialized_end=1122
  _CGAMENETWORKINGUI_MESSAGE._serialized_start=1124
  _CGAMENETWORKINGUI_MESSAGE._serialized_end=1213
  _CGAMENETWORKINGUI_CONNECTIONSUMMARY._serialized_start=1216
  _CGAMENETWORKINGUI_CONNECTIONSUMMARY._serialized_end=1446
  _CGAMENETWORKINGUI_APPSUMMARY._serialized_start=1449
  _CGAMENETWORKINGUI_APPSUMMARY._serialized_end=1651
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_offline.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.offline_ticket_pb2 as offline__ticket__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bsteammessages_offline.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a\x14offline_ticket.proto\"V\n&COffline_GetOfflineLogonTicket_Request\x12\x10\n\x08priority\x18\x01 \x01(\r\x12\x1a\n\x12perform_encryption\x18\x02 \x01(\x08\"\x82\x01\n\'COffline_GetOfflineLogonTicket_Response\x12\x19\n\x11serialized_ticket\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x12)\n\x10\x65ncrypted_ticket\x18\x03 \x01(\x0b\x32\x0f.Offline_Ticket\"0\n.COffline_GetUnsignedOfflineLogonTicket_Request\"O\n\x1b\x43Offline_OfflineLogonTicket\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x1d\n\x15rtime32_creation_time\x18\x02 \x01(\x07\"_\n/COffline_GetUnsignedOfflineLogonTicket_Response\x12,\n\x06ticket\x18\x01 \x01(\x0b\x32\x1c.COffline_OfflineLogonTicket2\xfa\x01\n\x07Offline\x12j\n\x15GetOfflineLogonTicket\x12\'.COffline_GetOfflineLogonTicket_Request\x1a(.COffline_GetOfflineLogonTicket_Response\x12\x82\x01\n\x1dGetUnsignedOfflineLogonTicket\x12/.COffline_GetUnsignedOfflineLogonTicket_Request\x1a\x30.COffline_GetUnsignedOfflineLogonTicket_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_offline_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _COFFLINE_GETOFFLINELOGONTICKET_REQUEST._serialized_start=113
  _COFFLINE_GETOFFLINELOGONTICKET_REQUEST._serialized_end=199
  _COFFLINE_GETOFFLINELOGONTICKET_RESPONSE._serialized_start=202
  _COFFLINE_GETOFFLINELOGONTICKET_RESPONSE._serialized_end=332
  _COFFLINE_GETUNSIGNEDOFFLINELOGONTICKET_REQUEST._serialized_start=334
  _COFFLINE_GETUNSIGNEDOFFLINELOGONTICKET_REQUEST._serialized_end=382
  _COFFLINE_OFFLINELOGONTICKET._serialized_start=384
  _COFFLINE_OFFLINELOGONTICKET._serialized_end=463
  _COFFLINE_GETUNSIGNEDOFFLINELOGONTICKET_RESPONSE._serialized_start=465
  _COFFLINE_GETUNSIGNEDOFFLINELOGONTICKET_RESPONSE._serialized_end=560
  _OFFLINE._serialized_start=563
  _OFFLINE._serialized_end=813
_builder.BuildServices(DESCRIPTOR, 'steammessages_offline_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: enums_productinfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x65nums_productinfo.proto*\xa2\x02\n\x14\x45\x43ontentDescriptorID\x12.\n*k_EContentDescriptor_NudityOrSexualContent\x10\x01\x12/\n+k_EContentDescriptor_FrequentViolenceOrGore\x10\x02\x12/\n+k_EContentDescriptor_AdultOnlySexualContent\x10\x03\x12\x30\n,k_EContentDescriptor_GratuitousSexualContent\x10\x04\x12)\n%k_EContentDescriptor_AnyMatureContent\x10\x05\x12\x1b\n\x17k_EContentDescriptorMAX\x10\x06\x42\x02H\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'enums_productinfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001'
  _ECONTENTDESCRIPTORID._serialized_start=28
  _ECONTENTDESCRIPTORID._serialized_end=318
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_remoteclient_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.steammessages_remoteclient_service_messages_pb2 as steammessages__remoteclient__service__messages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(steammessages_remoteclient_service.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a\x31steammessages_remoteclient_service_messages.proto2\x85\x0b\n\x0cRemoteClient\x12_\n\x0eGetPairingInfo\x12%.CRemoteClient_GetPairingInfo_Request\x1a&.CRemoteClient_GetPairingInfo_Response\x12?\n\x0cNotifyOnline\x12\".CRemoteClient_Online_Notification\x1a\x0b.NoResponse\x12\x65\n\x10GetRecentClients\x12\'.CRemoteClient_GetRecentClients_Request\x1a(.CRemoteClient_GetRecentClients_Response\x12\x65\n\x10MarkTaskComplete\x12\'.CRemoteClient_MarkTaskComplete_Request\x1a(.CRemoteClient_MarkTaskComplete_Response\x12I\n\x11NotifyReplyPacket\x12\'.CRemoteClient_ReplyPacket_Notification\x1a\x0b.NoResponse\x12n\n\x13\x41llocateRelayServer\x12*.CRemoteClient_AllocateRelayServer_Request\x1a+.CRemoteClient_AllocateRelayServer_Response\x12V\n\x0b\x41llocateSDR\x12\".CRemoteClient_AllocateSDR_Request\x1a#.CRemoteClient_AllocateSDR_Response\x12S\n\x18SendSteamBroadcastPacket\x12*.CRemoteClient_SteamBroadcast_Notification\x1a\x0b.NoResponse\x12O\n\x16SendSteamToSteamPacket\x12(.CRemoteClient_SteamToSteam_Notification\x1a\x0b.NoResponse\x12i\n\x1cSendRemotePlaySessionStarted\x12#.CRemotePlay_SessionStarted_Request\x1a$.CRemotePlay_SessionStarted_Response\x12U\n\x1cSendRemotePlaySessionStopped\x12(.CRemotePlay_SessionStopped_Notification\x1a\x0b.NoResponse\x12N\n\x1cSendRemotePlayTogetherPacket\x12!.CRemotePlayTogether_Notification\x1a\x0b.NoResponse\x12\x9b\x01\n\"CreateRemotePlayTogetherInvitation\x12\x39.CRemoteClient_CreateRemotePlayTogetherInvitation_Request\x1a:.CRemoteClient_CreateRemotePlayTogetherInvitation_Response\x12\x9b\x01\n\"DeleteRemotePlayTogetherInvitation\x12\x39.CRemoteClient_DeleteRemotePlayTogetherInvitation_Request\x1a:.CRemoteClient_DeleteRemotePlayTogetherInvitation_Response2\xeb\x04\n\x17RemoteClientSteamClient\x12[\n\x1aNotifyRegisterStatusUpdate\x12\x30.CRemoteClient_RegisterStatusUpdate_Notification\x1a\x0b.NoResponse\x12_\n\x1cNotifyUnregisterStatusUpdate\x12\x32.CRemoteClient_UnregisterStatusUpdate_Notification\x1a\x0b.NoResponse\x12K\n\x12NotifyRemotePacket\x12(.CRemoteClient_RemotePacket_Notification\x1a\x0b.NoResponse\x12U\n\x1aNotifySteamBroadcastPacket\x12*.CRemoteClient_SteamBroadcast_Notification\x1a\x0b.NoResponse\x12Q\n\x18NotifySteamToSteamPacket\x12(.CRemoteClient_SteamToSteam_Notification\x1a\x0b.NoResponse\x12P\n\x1eNotifyRemotePlayTogetherPacket\x12!.CRemotePlayTogether_Notification\x1a\x0b.NoResponse\x12\x43\n\x0eNotifyTaskList\x12$.CRemoteClient_TaskList_Notification\x1a\x0b.NoResponse\x1a\x04\xc0\xb5\x18\x02\x42\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_remoteclient_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _REMOTECLIENTSTEAMCLIENT._options = None
  _REMOTECLIENTSTEAMCLIENT._serialized_options = b'\300\265\030\002'
  _REMOTECLIENT._serialized_start=156
  _REMOTECLIENT._serialized_end=1569
  _REMOTECLIENTSTEAMCLIENT._serialized_start=1572
  _REMOTECLIENTSTEAMCLIENT._serialized_end=2191
_builder.BuildServices(DESCRIPTOR, 'steammessages_remoteclient_service_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_gamenotes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dwebuimessages_gamenotes.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"V\n\x1e\x43GameNotes_UploadImage_Request\x12\x13\n\x0b\x66ile_prefix\x18\x01 \x01(\t\x12\x11\n\tmime_type\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"3\n\x1f\x43GameNotes_UploadImage_Response\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t2c\n\tGameNotes\x12P\n\x0bUploadImage\x12\x1f.CGameNotes_UploadImage_Request\x1a .CGameNotes_UploadImage_Response\x1a\x04\x80\x97\"\x01\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_gamenotes_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _GAMENOTES._options = None
  _GAMENOTES._serialized_options = b'\200\227\"\001'
  _CGAMENOTES_UPLOADIMAGE_REQUEST._serialized_start=85
  _CGAMENOTES_UPLOADIMAGE_REQUEST._serialized_end=171
  _CGAMENOTES_UPLOADIMAGE_RESPONSE._serialized_start=173
  _CGAMENOTES_UPLOADIMAGE_RESPONSE._serialized_end=224
  _GAMENOTES._serialized_start=226
  _GAMENOTES._serialized_end=325
_builder.BuildServices(DESCRIPTOR, 'webuimessages_gamenotes_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_steamos.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2
import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bwebuimessages_steamos.proto\x1a\x0b\x65nums.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"}\n\x15\x43MsgFactoryResetState\x12\x12\n\nis_running\x18\x01 \x01(\x08\x12\x10\n\x08progress\x18\x02 \x01(\x05\x12\x1a\n\x12is_restart_pending\x18\x03 \x01(\x08\x12\"\n\x1artime_estimated_completion\x18\x04 \x01(\x07\"\x83\x07\n\x14\x43SteamOSManagerState\x12\x1c\n\x14is_service_available\x18\x01 \x01(\x08\x12\x12\n\nos_version\x18\x02 \x01(\t\x12%\n\x1dis_mandatory_update_available\x18\x03 \x01(\x08\x12T\n\x15startup_movie_variant\x18\x04 \x01(\x0e\x32\x15.EStartupMovieVariant:\x1ek_EStartupMovieVariant_Invalid\x12\'\n\x1fis_status_led_control_available\x18\x05 \x01(\x08\x12\x33\n\x13\x66\x61\x63tory_reset_state\x18\x06 \x01(\x0b\x32\x16.CMsgFactoryResetState\x12\x1e\n\x16is_tdp_limit_available\x18\x07 \x01(\x08\x12\x15\n\rtdp_limit_min\x18\x08 \x01(\x05\x12\x15\n\rtdp_limit_max\x18\t \x01(\x05\x12\x18\n\x10is_cec_available\x18\n \x01(\x08\x12\x1f\n\x17is_wifi_debug_supported\x18\x0b \x01(\x08\x12$\n\x1cis_wifi_debug_force_disabled\x18\x0c \x01(\x08\x12.\n&is_wifi_force_wpa_supplicant_supported\x18\r \x01(\x08\x12%\n\x1dis_manual_gpu_clock_available\x18\x0e \x01(\x08\x12\x1c\n\x14manual_gpu_clock_min\x18\x0f \x01(\x05\x12\x1c\n\x14manual_gpu_clock_max\x18\x10 \x01(\x05\x12/\n\'platform_performance_profiles_available\x18\x11 \x03(\t\x12,\n$platform_performance_profile_default\x18\x12 \x01(\t\x12$\n\x1cplatform_performance_profile\x18\x13 \x01(\t\x12!\n\x19is_charge_limit_available\x18\x14 \x01(\x08\x12\x18\n\x10\x63harge_limit_min\x18\x15 \x01(\x05\x12\x18\n\x10\x63harge_limit_max\x18\x16 \x01(\x05\x12\x1c\n\x14\x63harge_limit_default\x18\x17 \x01(\x05\x12\"\n\x1ais_screen_reader_supported\x18\x18 \x01(\x08\"\"\n CSteamOSManager_GetState_Request\"I\n!CSteamOSManager_GetState_Response\x12$\n\x05state\x18\x01 \x01(\x0b\x32\x15.CSteamOSManagerState\"+\n)CSteamOSManager_StateChanged_Notification\"f\n2CSteamOSManager_IsTelemetryHelperAvailable_Request\x12\x30\n\x05\x65type\x18\x01 \x01(\x0e\x32\x0b.ESLSHelper:\x14k_ESLSHelper_Invalid\"H\n3CSteamOSManager_IsTelemetryHelperAvailable_Response\x12\x11\n\tavailable\x18\x01 \x01(\x08\"2\n0CSteamOSManager_OptOutOfSideloadedClient_Request\"3\n1CSteamOSManager_OptOutOfSideloadedClient_Response\".\n,CSteamOSManager_ApplyMandatoryUpdate_Request\"/\n-CSteamOSManager_ApplyMandatoryUpdate_Response\"Q\n$CSteamOSManager_FactoryReset_Request\x12\x10\n\x08reset_os\x18\x01 \x01(\x08\x12\x17\n\x0freset_user_data\x18\x02 \x01(\x08\"\'\n%CSteamOSManager_FactoryReset_Response\"o\n\x11\x43SteamOSSLSPlugin\x12\x30\n\x05\x65type\x18\x01 \x01(\x0e\x32\x0b.ESLSHelper:\x14k_ESLSHelper_Invalid\x12\x14\n\x0cis_available\x18\x02 \x01(\x08\x12\x12\n\nis_enabled\x18\x03 \x01(\x08\"a\n\x10\x43SteamOSSLSState\x12\x14\n\x0cis_available\x18\x01 \x01(\x08\x12\x12\n\nis_enabled\x18\x02 \x01(\x08\x12#\n\x07plugins\x18\x03 \x03(\x0b\x32\x12.CSteamOSSLSPlugin\"\x1e\n\x1c\x43SteamOSSLS_GetState_Request\"A\n\x1d\x43SteamOSSLS_GetState_Response\x12 \n\x05state\x18\x01 \x01(\x0b\x32\x11.CSteamOSSLSState\"\'\n%CSteamOSSLS_StateChanged_Notification\"1\n\x1e\x43SteamOSSLS_SetEnabled_Request\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"!\n\x1f\x43SteamOSSLS_SetEnabled_Response\"i\n$CSteamOSSLS_SetPluginEnabled_Request\x12\x30\n\x05\x65type\x18\x01 \x01(\x0e\x32\x0b.ESLSHelper:\x14k_ESLSHelper_Invalid\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\"\'\n%CSteamOSSLS_SetPluginEnabled_Response2\x97\x04\n\x0eSteamOSManager\x12Q\n\x08GetState\x12!.CSteamOSManager_GetState_Request\x1a\".CSteamOSManager_GetState_Response\x12R\n\x12NotifyStateChanged\x12*.CSteamOSManager_StateChanged_Notification\x1a\x10.WebUINoResponse\x12\x81\x01\n\x18OptOutOfSideloadedClient\x12\x31.CSteamOSManager_OptOutOfSideloadedClient_Request\x1a\x32.CSteamOSManager_OptOutOfSideloadedClient_Response\x12u\n\x14\x41pplyMandatoryUpdate\x12-.CSteamOSManager_ApplyMandatoryUpdate_Request\x1a..CSteamOSManager_ApplyMandatoryUpdate_Response\x12]\n\x0c\x46\x61\x63toryReset\x12%.CSteamOSManager_FactoryReset_Request\x1a&.CSteamOSManager_FactoryReset_Response\x1a\x04\x80\x97\"\x01\x32\xe1\x02\n\nSteamOSSLS\x12I\n\x08GetState\x12\x1d.CSteamOSSLS_GetState_Request\x1a\x1e.CSteamOSSLS_GetState_Response\x12N\n\x12NotifyStateChanged\x12&.CSteamOSSLS_StateChanged_Notification\x1a\x10.WebUINoResponse\x12O\n\nSetEnabled\x12\x1f.CSteamOSSLS_SetEnabled_Request\x1a .CSteamOSSLS_SetEnabled_Response\x12\x61\n\x10SetPluginEnabled\x12%.CSteamOSSLS_SetPluginEnabled_Request\x1a&.CSteamOSSLS_SetPluginEnabled_Response\x1a\x04\x80\x97\"\x01\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_steamos_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _STEAMOSMANAGER._options = None
  _STEAMOSMANAGER._serialized_options = b'\200\227\"\001'
  _STEAMOSSLS._options = None
  _STEAMOSSLS._serialized_options = b'\200\227\"\001'
  _CMSGFACTORYRESETSTATE._serialized_start=96
  _CMSGFACTORYRESETSTATE._serialized_end=221
  _CSTEAMOSMANAGERSTATE._serialized_start=224
  _CSTEAMOSMANAGERSTATE._serialized_end=1123
  _CSTEAMOSMANAGER_GETSTATE_REQUEST._serialized_start=1125
  _CSTEAMOSMANAGER_GETSTATE_REQUEST._serialized_end=1159
  _CSTEAMOSMANAGER_GETSTATE_RESPONSE._serialized_start=1161
  _CSTEAMOSMANAGER_GETSTATE_RESPONSE._serialized_end=1234
  _CSTEAMOSMANAGER_STATECHANGED_NOTIFICATION._serialized_start=1236
  _CSTEAMOSMANAGER_STATECHANGED_NOTIFICATION._serialized_end=1279
  _CSTEAMOSMANAGER_ISTELEMETRYHELPERAVAILABLE_REQUEST._serialized_start=1281
  _CSTEAMOSMANAGER_ISTELEMETRYHELPERAVAILABLE_REQUEST._serialized_end=1383
  _CSTEAMOSMANAGER_ISTELEMETRYHELPERAVAILABLE_RESPONSE._serialized_start=1385
  _CSTEAMOSMANAGER_ISTELEMETRYHELPERAVAILABLE_RESPONSE._serialized_end=1457
  _CSTEAMOSMANAGER_OPTOUTOFSIDELOADEDCLIENT_REQUEST._serialized_start=1459
  _CSTEAMOSMANAGER_OPTOUTOFSIDELOADEDCLIENT_REQUEST._serialized_end=1509
  _CSTEAMOSMANAGER_OPTOUTOFSIDELOADEDCLIENT_RESPONSE._serialized_start=1511
  _CSTEAMOSMANAGER_OPTOUTOFSIDELOADEDCLIENT_RESPONSE._serialized_end=1562
  _CSTEAMOSMANAGER_APPLYMANDATORYUPDATE_REQUEST._serialized_start=1564
  _CSTEAMOSMANAGER_APPLYMANDATORYUPDATE_REQUEST._serialized_end=1610
  _CSTEAMOSMANAGER_APPLYMANDATORYUPDATE_RESPONSE._serialized_start=1612
  _CSTEAMOSMANAGER_APPLYMANDATORYUPDATE_RESPONSE._serialized_end=1659
  _CSTEAMOSMANAGER_FACTORYRESET_REQUEST._serialized_start=1661
  _CSTEAMOSMANAGER_FACTORYRESET_REQUEST._serialized_end=1742
  _CSTEAMOSMANAGER_FACTORYRESET_RESPONSE._serialized_start=1744
  _CSTEAMOSMANAGER_FACTORYRESET_RESPONSE._serialized_end=1783
  _CSTEAMOSSLSPLUGIN._serialized_start=1785
  _CSTEAMOSSLSPLUGIN._serialized_end=1896
  _CSTEAMOSSLSSTATE._serialized_start=1898
  _CSTEAMOSSLSSTATE._serialized_end=1995
  _CSTEAMOSSLS_GETSTATE_REQUEST._serialized_start=1997
  _CSTEAMOSSLS_GETSTATE_REQUEST._serialized_end=2027
  _CSTEAMOSSLS_GETSTATE_RESPONSE._serialized_start=2029
  _CSTEAMOSSLS_GETSTATE_RESPONSE._serialized_end=2094
  _CSTEAMOSSLS_STATECHANGED_NOTIFICATION._serialized_start=2096
  _CSTEAMOSSLS_STATECHANGED_NOTIFICATION._serialized_end=2135
  _CSTEAMOSSLS_SETENABLED_REQUEST._serialized_start=2137
  _CSTEAMOSSLS_SETENABLED_REQUEST._serialized_end=2186
  _CSTEAMOSSLS_SETENABLED_RESPONSE._serialized_start=2188
  _CSTEAMOSSLS_SETENABLED_RESPONSE._serialized_end=2221
  _CSTEAMOSSLS_SETPLUGINENABLED_REQUEST._serialized_start=2223
  _CSTEAMOSSLS_SETPLUGINENABLED_REQUEST._serialized_end=2328
  _CSTEAMOSSLS_SETPLUGINENABLED_RESPONSE._serialized_start=2330
  _CSTEAMOSSLS_SETPLUGINENABLED_RESPONSE._serialized_end=2369
  _STEAMOSMANAGER._serialized_start=2372
  _STEAMOSMANAGER._serialized_end=2907
  _STEAMOSSLS._serialized_start=2910
  _STEAMOSSLS._serialized_end=3263
_builder.BuildServices(DESCRIPTOR, 'webuimessages_steamos_pb2', globals())
# @@protoc_insertion_point(module_scope)



"""
All high level features of :class:`steam.client.SteamClient` are implemented here in separate submodules.
"""
from steam.client.builtins.user import User
from steam.client.builtins.web import Web
from steam.client.builtins.unified_messages import UnifiedMessages
from steam.client.builtins.leaderboards import Leaderboards
from steam.client.builtins.gameservers import GameServers
from steam.client.builtins.friends import Friends
from steam.client.builtins.apps import Apps

class BuiltinBase(GameServers, UnifiedMessages, User, Web, Leaderboards, Friends, Apps):
    """
    This object is used as base to implement all high level functionality.
    The features are separated into submodules.
    """
    pass



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver_gameservers.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,steammessages_clientserver_gameservers.proto\x1a\x18steammessages_base.proto\"\xed\x01\n\x10\x43MsgGSServerType\x12\x15\n\rapp_id_served\x18\x01 \x01(\r\x12\r\n\x05\x66lags\x18\x02 \x01(\r\x12\"\n\x1a\x64\x65precated_game_ip_address\x18\x03 \x01(\r\x12\x11\n\tgame_port\x18\x04 \x01(\r\x12\x10\n\x08game_dir\x18\x05 \x01(\t\x12\x14\n\x0cgame_version\x18\x06 \x01(\t\x12\x17\n\x0fgame_query_port\x18\x07 \x01(\r\x12\x17\n\x0fgame_port_local\x18\n \x01(\r\x12\x11\n\tsdr_logon\x18\x08 \x01(\x0c\x12\x0f\n\x07\x66\x61ke_ip\x18\t \x01(\x07\":\n\x11\x43MsgGSStatusReply\x12\x11\n\tis_secure\x18\x01 \x01(\x08\x12\x12\n\nis_valveds\x18\x02 \x01(\x08\"\xa9\x01\n\x10\x43MsgGSPlayerList\x12)\n\x07players\x18\x01 \x03(\x0b\x32\x18.CMsgGSPlayerList.Player\x1aj\n\x06Player\x12\x10\n\x08steam_id\x18\x01 \x01(\x04\x12\x1c\n\x14\x64\x65precated_public_ip\x18\x02 \x01(\r\x12\r\n\x05token\x18\x03 \x01(\x0c\x12!\n\tpublic_ip\x18\x04 \x01(\x0b\x32\x0e.CMsgIPAddress\"u\n\x11\x43MsgGSUserPlaying\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x1c\n\x14\x64\x65precated_public_ip\x18\x02 \x01(\r\x12\r\n\x05token\x18\x03 \x01(\x0c\x12!\n\tpublic_ip\x18\x04 \x01(\x0b\x32\x0e.CMsgIPAddress\"*\n\x16\x43MsgGSDisconnectNotice\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\"\x97\x04\n\x12\x43MsgGameServerData\x12\x10\n\x08revision\x18\x18 \x01(\r\x12\x12\n\nquery_port\x18\x03 \x01(\r\x12\x11\n\tgame_port\x18\x04 \x01(\r\x12\x16\n\x0espectator_port\x18\x05 \x01(\r\x12\x13\n\x0bserver_name\x18\x16 \x01(\t\x12\x18\n\x10game_description\x18\x1d \x01(\t\x12\x1d\n\x15spectator_server_name\x18\x1b \x01(\t\x12\x0f\n\x07\x66\x61ke_ip\x18\x1c \x01(\x07\x12\x19\n\x11sdr_ping_location\x18\x1e \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x06 \x01(\r\x12\x0f\n\x07gamedir\x18\x07 \x01(\t\x12\x0f\n\x07version\x18\x08 \x01(\t\x12\x0f\n\x07product\x18\t \x01(\t\x12\x0e\n\x06region\x18\n \x01(\t\x12+\n\x07players\x18\x0b \x03(\x0b\x32\x1a.CMsgGameServerData.Player\x12\x13\n\x0bmax_players\x18\x0c \x01(\r\x12\x11\n\tbot_count\x18\r \x01(\r\x12\x10\n\x08password\x18\x0e \x01(\x08\x12\x0e\n\x06secure\x18\x0f \x01(\x08\x12\x11\n\tdedicated\x18\x10 \x01(\x08\x12\n\n\x02os\x18\x11 \x01(\t\x12\x11\n\tgame_data\x18\x12 \x01(\t\x12\x11\n\tgame_type\x18\x14 \x01(\t\x12\x0b\n\x03map\x18\x15 \x01(\t\x1a\x1a\n\x06Player\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\"M\n\x14\x43MsgGameServerRemove\x12\x1a\n\x12legacy_steam_id_gs\x18\x01 \x01(\x06\x12\x19\n\x11legacy_query_port\x18\x03 \x01(\r\"\x9d\x01\n\x18\x43MsgClientGMSServerQuery\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x17\n\x0fgeo_location_ip\x18\x02 \x01(\r\x12\x13\n\x0bregion_code\x18\x03 \x01(\r\x12\x13\n\x0b\x66ilter_text\x18\x04 \x01(\t\x12\x13\n\x0bmax_servers\x18\x05 \x01(\r\x12\x19\n\x11sdr_ping_location\x18\x06 \x01(\t\"\xa5\x07\n CMsgGMSClientServerQueryResponse\x12\x39\n\x07servers\x18\x01 \x03(\x0b\x32(.CMsgGMSClientServerQueryResponse.Server\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x45\n\x13\x64\x65\x66\x61ult_server_data\x18\x03 \x01(\x0b\x32(.CMsgGMSClientServerQueryResponse.Server\x12\x16\n\x0eserver_strings\x18\x04 \x03(\t\x1a\xa0\x05\n\x06Server\x12\x1c\n\x14\x64\x65precated_server_ip\x18\x01 \x01(\r\x12\x12\n\nquery_port\x18\x02 \x01(\r\x12\x14\n\x0c\x61uth_players\x18\x03 \x01(\r\x12!\n\tserver_ip\x18\x04 \x01(\x0b\x32\x0e.CMsgIPAddress\x12\x10\n\x08steam_id\x18\x06 \x01(\x06\x12\x10\n\x08revision\x18\x07 \x01(\r\x12\x0f\n\x07players\x18\x08 \x01(\r\x12\x11\n\tgame_port\x18\t \x01(\r\x12\x11\n\tsdr_popid\x18\n \x01(\x07\x12\x19\n\x11sdr_ping_location\x18  \x01(\t\x12\r\n\x05\x66lags\x18\x0b \x01(\r\x12\x0e\n\x06\x61pp_id\x18\x0c \x01(\r\x12\x13\n\x0bmax_players\x18\r \x01(\r\x12\x0c\n\x04\x62ots\x18\x0e \x01(\r\x12\x16\n\x0espectator_port\x18\x0f \x01(\r\x12\x13\n\x0bgamedir_str\x18\x10 \x01(\t\x12\x18\n\x10gamedir_strindex\x18\x11 \x01(\r\x12\x0f\n\x07map_str\x18\x12 \x01(\t\x12\x14\n\x0cmap_strindex\x18\x13 \x01(\r\x12\x10\n\x08name_str\x18\x14 \x01(\t\x12\x15\n\rname_strindex\x18\x15 \x01(\r\x12\x1c\n\x14game_description_str\x18\x16 \x01(\t\x12!\n\x19game_description_strindex\x18\x17 \x01(\r\x12\x13\n\x0bversion_str\x18\x18 \x01(\t\x12\x18\n\x10version_strindex\x18\x19 \x01(\r\x12\x14\n\x0cgametype_str\x18\x1a \x01(\t\x12\x19\n\x11gametype_strindex\x18\x1b \x01(\r\x12\x1a\n\x12spectator_name_str\x18\x1e \x01(\t\x12\x1f\n\x17spectator_name_strindex\x18\x1f \x01(\r\"5\n\x06\x45\x46lags\x12\x17\n\x13k_EFlag_HasPassword\x10\x01\x12\x12\n\x0ek_EFlag_Secure\x10\x02\"O\n\x17\x43MsgGameServerOutOfDate\x12\x13\n\x0bsteam_id_gs\x18\x01 \x01(\x06\x12\x0e\n\x06reject\x18\x02 \x01(\x08\x12\x0f\n\x07message\x18\x03 \x01(\t\"0\n\x17\x43MsgGSAssociateWithClan\x12\x15\n\rsteam_id_clan\x18\x01 \x01(\x06\"L\n\x1f\x43MsgGSAssociateWithClanResponse\x12\x15\n\rsteam_id_clan\x18\x01 \x01(\x06\x12\x12\n\x07\x65result\x18\x02 \x01(\r:\x01\x32\"A\n#CMsgGSComputeNewPlayerCompatibility\x12\x1a\n\x12steam_id_candidate\x18\x01 \x01(\x06\"\xcf\x01\n+CMsgGSComputeNewPlayerCompatibilityResponse\x12\x1a\n\x12steam_id_candidate\x18\x01 \x01(\x06\x12\x12\n\x07\x65result\x18\x02 \x01(\r:\x01\x32\x12\x16\n\x0eis_clan_member\x18\x03 \x01(\x08\x12\x18\n\x10\x63t_dont_like_you\x18\x04 \x01(\x05\x12\x18\n\x10\x63t_you_dont_like\x18\x05 \x01(\x05\x12$\n\x1c\x63t_clanmembers_dont_like_you\x18\x06 \x01(\x05\x42\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_clientserver_gameservers_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _CMSGGSSERVERTYPE._serialized_start=75
  _CMSGGSSERVERTYPE._serialized_end=312
  _CMSGGSSTATUSREPLY._serialized_start=314
  _CMSGGSSTATUSREPLY._serialized_end=372
  _CMSGGSPLAYERLIST._serialized_start=375
  _CMSGGSPLAYERLIST._serialized_end=544
  _CMSGGSPLAYERLIST_PLAYER._serialized_start=438
  _CMSGGSPLAYERLIST_PLAYER._serialized_end=544
  _CMSGGSUSERPLAYING._serialized_start=546
  _CMSGGSUSERPLAYING._serialized_end=663
  _CMSGGSDISCONNECTNOTICE._serialized_start=665
  _CMSGGSDISCONNECTNOTICE._serialized_end=707
  _CMSGGAMESERVERDATA._serialized_start=710
  _CMSGGAMESERVERDATA._serialized_end=1245
  _CMSGGAMESERVERDATA_PLAYER._serialized_start=1219
  _CMSGGAMESERVERDATA_PLAYER._serialized_end=1245
  _CMSGGAMESERVERREMOVE._serialized_start=1247
  _CMSGGAMESERVERREMOVE._serialized_end=1324
  _CMSGCLIENTGMSSERVERQUERY._serialized_start=1327
  _CMSGCLIENTGMSSERVERQUERY._serialized_end=1484
  _CMSGGMSCLIENTSERVERQUERYRESPONSE._serialized_start=1487
  _CMSGGMSCLIENTSERVERQUERYRESPONSE._serialized_end=2420
  _CMSGGMSCLIENTSERVERQUERYRESPONSE_SERVER._serialized_start=1693
  _CMSGGMSCLIENTSERVERQUERYRESPONSE_SERVER._serialized_end=2365
  _CMSGGMSCLIENTSERVERQUERYRESPONSE_EFLAGS._serialized_start=2367
  _CMSGGMSCLIENTSERVERQUERYRESPONSE_EFLAGS._serialized_end=2420
  _CMSGGAMESERVEROUTOFDATE._serialized_start=2422
  _CMSGGAMESERVEROUTOFDATE._serialized_end=2501
  _CMSGGSASSOCIATEWITHCLAN._serialized_start=2503
  _CMSGGSASSOCIATEWITHCLAN._serialized_end=2551
  _CMSGGSASSOCIATEWITHCLANRESPONSE._serialized_start=2553
  _CMSGGSASSOCIATEWITHCLANRESPONSE._serialized_end=2629
  _CMSGGSCOMPUTENEWPLAYERCOMPATIBILITY._serialized_start=2631
  _CMSGGSCOMPUTENEWPLAYERCOMPATIBILITY._serialized_end=2696
  _CMSGGSCOMPUTENEWPLAYERCOMPATIBILITYRESPONSE._serialized_start=2699
  _CMSGGSCOMPUTENEWPLAYERCOMPATIBILITYRESPONSE._serialized_end=2906
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.encrypted_app_ticket_pb2 as encrypted__app__ticket__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n steammessages_clientserver.proto\x1a\x18steammessages_base.proto\x1a\x1a\x65ncrypted_app_ticket.proto\"j\n\"CMsgClientRegisterAuthTicketWithCM\x12\x18\n\x10protocol_version\x18\x01 \x01(\r\x12\x0e\n\x06ticket\x18\x03 \x01(\x0c\x12\x1a\n\x12\x63lient_instance_id\x18\x04 \x01(\x04\"\xd1\x01\n\x1c\x43MsgClientTicketAuthComplete\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x0f\n\x07game_id\x18\x02 \x01(\x06\x12\x0e\n\x06\x65state\x18\x03 \x01(\r\x12\x1e\n\x16\x65\x61uth_session_response\x18\x04 \x01(\r\x12\x19\n\x11\x44\x45PRECATED_ticket\x18\x05 \x01(\x0c\x12\x12\n\nticket_crc\x18\x06 \x01(\r\x12\x17\n\x0fticket_sequence\x18\x07 \x01(\r\x12\x16\n\x0eowner_steam_id\x18\x08 \x01(\x06\"\xa3\x01\n\x1b\x43MsgClientP2PConnectionInfo\x12\x15\n\rsteam_id_dest\x18\x01 \x01(\x06\x12\x14\n\x0csteam_id_src\x18\x02 \x01(\x06\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\x11\n\tcandidate\x18\x04 \x01(\x0c\x12 \n\x18legacy_connection_id_src\x18\x05 \x01(\x06\x12\x12\n\nrendezvous\x18\x06 \x01(\x0c\"\xc3\x01\n\x1f\x43MsgClientP2PConnectionFailInfo\x12\x15\n\rsteam_id_dest\x18\x01 \x01(\x06\x12\x14\n\x0csteam_id_src\x18\x02 \x01(\x06\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\x1a\n\x12\x65p2p_session_error\x18\x04 \x01(\r\x12\x1a\n\x12\x63onnection_id_dest\x18\x05 \x01(\x06\x12\x14\n\x0c\x63lose_reason\x18\x07 \x01(\r\x12\x15\n\rclose_message\x18\x08 \x01(\t\"C\n\x1f\x43MsgClientNetworkingCertRequest\x12\x10\n\x08key_data\x18\x02 \x01(\x0c\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\"V\n\x1d\x43MsgClientNetworkingCertReply\x12\x0c\n\x04\x63\x65rt\x18\x04 \x01(\x0c\x12\x11\n\tca_key_id\x18\x05 \x01(\x06\x12\x14\n\x0c\x63\x61_signature\x18\x06 \x01(\x0c\"7\n%CMsgClientNetworkingMobileCertRequest\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\";\n#CMsgClientNetworkingMobileCertReply\x12\x14\n\x0c\x65ncoded_cert\x18\x01 \x01(\t\"1\n\x1f\x43MsgClientGetAppOwnershipTicket\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\"]\n\'CMsgClientGetAppOwnershipTicketResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x0e\n\x06ticket\x18\x03 \x01(\x0c\"\'\n\x16\x43MsgClientSessionToken\x12\r\n\x05token\x18\x01 \x01(\x04\"M\n\x1b\x43MsgClientGameConnectTokens\x12\x1e\n\x12max_tokens_to_keep\x18\x01 \x01(\r:\x02\x31\x30\x12\x0e\n\x06tokens\x18\x02 \x03(\x0c\"\x99\t\n\x15\x43MsgClientGamesPlayed\x12\x37\n\x0cgames_played\x18\x01 \x03(\x0b\x32!.CMsgClientGamesPlayed.GamePlayed\x12\x16\n\x0e\x63lient_os_type\x18\x02 \x01(\r\x12\x1d\n\x15\x63loud_gaming_platform\x18\x03 \x01(\r\x12\x1f\n\x17recent_reauthentication\x18\x04 \x01(\x08\x1aU\n\x0bProcessInfo\x12\x12\n\nprocess_id\x18\x01 \x01(\r\x12\x19\n\x11process_id_parent\x18\x02 \x01(\r\x12\x17\n\x0fparent_is_steam\x18\x03 \x01(\x08\x1a\x97\x07\n\nGamePlayed\x12\x13\n\x0bsteam_id_gs\x18\x01 \x01(\x04\x12\x0f\n\x07game_id\x18\x02 \x01(\x06\x12\"\n\x1a\x64\x65precated_game_ip_address\x18\x03 \x01(\r\x12\x11\n\tgame_port\x18\x04 \x01(\r\x12\x11\n\tis_secure\x18\x05 \x01(\x08\x12\r\n\x05token\x18\x06 \x01(\x0c\x12\x17\n\x0fgame_extra_info\x18\x07 \x01(\t\x12\x16\n\x0egame_data_blob\x18\x08 \x01(\x0c\x12\x12\n\nprocess_id\x18\t \x01(\r\x12\x1d\n\x15streaming_provider_id\x18\n \x01(\r\x12\x12\n\ngame_flags\x18\x0b \x01(\r\x12\x10\n\x08owner_id\x18\x0c \x01(\r\x12\x15\n\rvr_hmd_vendor\x18\r \x01(\t\x12\x14\n\x0cvr_hmd_model\x18\x0e \x01(\t\x12\x1d\n\x12launch_option_type\x18\x0f \x01(\r:\x01\x30\x12#\n\x17primary_controller_type\x18\x10 \x01(\x05:\x02-1\x12\'\n\x1fprimary_steam_controller_serial\x18\x11 \x01(\t\x12\'\n\x1ctotal_steam_controller_count\x18\x12 \x01(\r:\x01\x30\x12+\n total_non_steam_controller_count\x18\x13 \x01(\r:\x01\x30\x12&\n\x1b\x63ontroller_workshop_file_id\x18\x14 \x01(\x04:\x01\x30\x12\x18\n\rlaunch_source\x18\x15 \x01(\r:\x01\x30\x12\x16\n\x0evr_hmd_runtime\x18\x16 \x01(\r\x12\'\n\x0fgame_ip_address\x18\x17 \x01(\x0b\x32\x0e.CMsgIPAddress\x12%\n\x1a\x63ontroller_connection_type\x18\x18 \x01(\r:\x01\x30\x12\x18\n\x10game_os_platform\x18\x19 \x01(\x05\x12\x15\n\rgame_build_id\x18\x1a \x01(\r\x12\x19\n\x0e\x63ompat_tool_id\x18\x1b \x01(\r:\x01\x30\x12\x17\n\x0f\x63ompat_tool_cmd\x18\x1c \x01(\t\x12\x1c\n\x14\x63ompat_tool_build_id\x18\x1d \x01(\r\x12\x11\n\tbeta_name\x18\x1e \x01(\t\x12\x13\n\x0b\x64lc_context\x18\x1f \x01(\r\x12;\n\x0fprocess_id_list\x18  \x03(\x0b\x32\".CMsgClientGamesPlayed.ProcessInfo\"9\n\rCMsgGSApprove\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x16\n\x0eowner_steam_id\x18\x02 \x01(\x06\"I\n\nCMsgGSDeny\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x14\n\x0c\x65\x64\x65ny_reason\x18\x02 \x01(\x05\x12\x13\n\x0b\x64\x65ny_string\x18\x03 \x01(\t\"4\n\nCMsgGSKick\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x14\n\x0c\x65\x64\x65ny_reason\x18\x02 \x01(\x05\"\xc8\x01\n\x12\x43MsgClientAuthList\x12\x13\n\x0btokens_left\x18\x01 \x01(\r\x12\x18\n\x10last_request_seq\x18\x02 \x01(\r\x12$\n\x1clast_request_seq_from_server\x18\x03 \x01(\r\x12 \n\x07tickets\x18\x04 \x03(\x0b\x32\x0f.CMsgAuthTicket\x12\x0f\n\x07\x61pp_ids\x18\x05 \x03(\r\x12\x18\n\x10message_sequence\x18\x06 \x01(\r\x12\x10\n\x08\x66iltered\x18\x07 \x01(\x08\"V\n\x15\x43MsgClientAuthListAck\x12\x12\n\nticket_crc\x18\x01 \x03(\r\x12\x0f\n\x07\x61pp_ids\x18\x02 \x03(\r\x12\x18\n\x10message_sequence\x18\x03 \x01(\r\"\x8e\x04\n\x15\x43MsgClientLicenseList\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x30\n\x08licenses\x18\x02 \x03(\x0b\x32\x1e.CMsgClientLicenseList.License\x1a\xae\x03\n\x07License\x12\x12\n\npackage_id\x18\x01 \x01(\r\x12\x14\n\x0ctime_created\x18\x02 \x01(\x07\x12\x19\n\x11time_next_process\x18\x03 \x01(\x07\x12\x14\n\x0cminute_limit\x18\x04 \x01(\x05\x12\x14\n\x0cminutes_used\x18\x05 \x01(\x05\x12\x16\n\x0epayment_method\x18\x06 \x01(\r\x12\r\n\x05\x66lags\x18\x07 \x01(\r\x12\x1d\n\x15purchase_country_code\x18\x08 \x01(\t\x12\x14\n\x0clicense_type\x18\t \x01(\r\x12\x16\n\x0eterritory_code\x18\n \x01(\x05\x12\x15\n\rchange_number\x18\x0b \x01(\x05\x12\x10\n\x08owner_id\x18\x0c \x01(\r\x12\x16\n\x0einitial_period\x18\r \x01(\r\x12\x19\n\x11initial_time_unit\x18\x0e \x01(\r\x12\x16\n\x0erenewal_period\x18\x0f \x01(\r\x12\x19\n\x11renewal_time_unit\x18\x10 \x01(\r\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x11 \x01(\x04\x12\x19\n\x11master_package_id\x18\x12 \x01(\r\"\xaa\x01\n\x1a\x43MsgClientIsLimitedAccount\x12\x1b\n\x13\x62is_limited_account\x18\x01 \x01(\x08\x12\x1c\n\x14\x62is_community_banned\x18\x02 \x01(\x08\x12\x1a\n\x12\x62is_locked_account\x18\x03 \x01(\x08\x12\x35\n-bis_limited_account_allowed_to_invite_friends\x18\x04 \x01(\x08\"\xa7\x01\n\x1e\x43MsgClientRequestedClientStats\x12\x42\n\rstats_to_send\x18\x01 \x03(\x0b\x32+.CMsgClientRequestedClientStats.StatsToSend\x1a\x41\n\x0bStatsToSend\x12\x13\n\x0b\x63lient_stat\x18\x01 \x01(\r\x12\x1d\n\x15stat_aggregate_method\x18\x02 \x01(\r\"\xc0\x01\n\x0f\x43MsgClientStat2\x12\x30\n\x0bstat_detail\x18\x01 \x03(\x0b\x32\x1b.CMsgClientStat2.StatDetail\x1a{\n\nStatDetail\x12\x13\n\x0b\x63lient_stat\x18\x01 \x01(\r\x12\x10\n\x08ll_value\x18\x02 \x01(\x03\x12\x13\n\x0btime_of_day\x18\x03 \x01(\r\x12\x0f\n\x07\x63\x65ll_id\x18\x04 \x01(\r\x12\x10\n\x08\x64\x65pot_id\x18\x05 \x01(\r\x12\x0e\n\x06\x61pp_id\x18\x06 \x01(\r\"r\n\x16\x43MsgClientInviteToGame\x12\x15\n\rsteam_id_dest\x18\x01 \x01(\x06\x12\x14\n\x0csteam_id_src\x18\x02 \x01(\x06\x12\x16\n\x0e\x63onnect_string\x18\x03 \x01(\t\x12\x13\n\x0bremote_play\x18\x04 \x01(\t\"\xb9\x01\n\x14\x43MsgClientChatInvite\x12\x18\n\x10steam_id_invited\x18\x01 \x01(\x06\x12\x15\n\rsteam_id_chat\x18\x02 \x01(\x06\x12\x17\n\x0fsteam_id_patron\x18\x03 \x01(\x06\x12\x15\n\rchatroom_type\x18\x04 \x01(\x05\x12\x1c\n\x14steam_id_friend_chat\x18\x05 \x01(\x06\x12\x11\n\tchat_name\x18\x06 \x01(\t\x12\x0f\n\x07game_id\x18\x07 \x01(\x06\"\xf9\x08\n\x19\x43MsgClientConnectionStats\x12;\n\x0bstats_logon\x18\x01 \x01(\x0b\x32&.CMsgClientConnectionStats.Stats_Logon\x12;\n\x0bstats_vconn\x18\x02 \x01(\x0b\x32&.CMsgClientConnectionStats.Stats_VConn\x1a\xd3\x02\n\x0bStats_Logon\x12\x18\n\x10\x63onnect_attempts\x18\x01 \x01(\x05\x12\x19\n\x11\x63onnect_successes\x18\x02 \x01(\x05\x12\x18\n\x10\x63onnect_failures\x18\x03 \x01(\x05\x12\x1b\n\x13\x63onnections_dropped\x18\x04 \x01(\x05\x12\x17\n\x0fseconds_running\x18\x05 \x01(\r\x12\x1c\n\x14msec_tologonthistime\x18\x06 \x01(\r\x12\x15\n\rcount_bad_cms\x18\x07 \x01(\r\x12\x1b\n\x13no_udp_connectivity\x18\x08 \x01(\x08\x12\x1b\n\x13no_tcp_connectivity\x18\t \x01(\x08\x12%\n\x1dno_websocket_443_connectivity\x18\n \x01(\x08\x12)\n!no_websocket_non_443_connectivity\x18\x0b \x01(\x08\x1aq\n\tStats_UDP\x12\x11\n\tpkts_sent\x18\x01 \x01(\x04\x12\x12\n\nbytes_sent\x18\x02 \x01(\x04\x12\x11\n\tpkts_recv\x18\x03 \x01(\x04\x12\x16\n\x0epkts_processed\x18\x04 \x01(\x04\x12\x12\n\nbytes_recv\x18\x05 \x01(\x04\x1a\x98\x04\n\x0bStats_VConn\x12\x17\n\x0f\x63onnections_udp\x18\x01 \x01(\r\x12\x17\n\x0f\x63onnections_tcp\x18\x02 \x01(\r\x12\x37\n\tstats_udp\x18\x03 \x01(\x0b\x32$.CMsgClientConnectionStats.Stats_UDP\x12\x16\n\x0epkts_abandoned\x18\x04 \x01(\x04\x12\x19\n\x11\x63onn_req_received\x18\x05 \x01(\x04\x12\x13\n\x0bpkts_resent\x18\x06 \x01(\x04\x12\x11\n\tmsgs_sent\x18\x07 \x01(\x04\x12\x18\n\x10msgs_sent_failed\x18\x08 \x01(\x04\x12\x11\n\tmsgs_recv\x18\t \x01(\x04\x12\x16\n\x0e\x64\x61tagrams_sent\x18\n \x01(\x04\x12\x16\n\x0e\x64\x61tagrams_recv\x18\x0b \x01(\x04\x12\x15\n\rbad_pkts_recv\x18\x0c \x01(\x04\x12\x1e\n\x16unknown_conn_pkts_recv\x18\r \x01(\x04\x12\x18\n\x10missed_pkts_recv\x18\x0e \x01(\x04\x12\x15\n\rdup_pkts_recv\x18\x0f \x01(\x04\x12!\n\x19\x66\x61iled_connect_challenges\x18\x10 \x01(\x04\x12\x1d\n\x15micro_sec_avg_latency\x18\x11 \x01(\r\x12\x1d\n\x15micro_sec_min_latency\x18\x12 \x01(\r\x12\x1d\n\x15micro_sec_max_latency\x18\x13 \x01(\r\"\xd2\x01\n\x1a\x43MsgClientServersAvailable\x12R\n\x16server_types_available\x18\x01 \x03(\x0b\x32\x32.CMsgClientServersAvailable.Server_Types_Available\x12%\n\x1dserver_type_for_auth_services\x18\x02 \x01(\r\x1a\x39\n\x16Server_Types_Available\x12\x0e\n\x06server\x18\x01 \x01(\r\x12\x0f\n\x07\x63hanged\x18\x02 \x01(\x08\"?\n$CMsgClientReportOverlayDetourFailure\x12\x17\n\x0f\x66\x61ilure_strings\x18\x01 \x03(\t\"G\n#CMsgClientRequestEncryptedAppTicket\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x10\n\x08userdata\x18\x02 \x01(\x0c\"\x84\x01\n+CMsgClientRequestEncryptedAppTicketResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x12\n\x07\x65result\x18\x02 \x01(\x05:\x01\x32\x12\x31\n\x14\x65ncrypted_app_ticket\x18\x03 \x01(\x0b\x32\x13.EncryptedAppTicket\"\xb5\x01\n\x1a\x43MsgClientWalletInfoUpdate\x12\x12\n\nhas_wallet\x18\x01 \x01(\x08\x12\x0f\n\x07\x62\x61lance\x18\x02 \x01(\x05\x12\x10\n\x08\x63urrency\x18\x03 \x01(\x05\x12\x17\n\x0f\x62\x61lance_delayed\x18\x04 \x01(\x05\x12\x17\n\tbalance64\x18\x05 \x01(\x03\x42\x04\xa0\xb6\x18\x01\x12\x1f\n\x11\x62\x61lance64_delayed\x18\x06 \x01(\x03\x42\x04\xa0\xb6\x18\x01\x12\r\n\x05realm\x18\x07 \x01(\x05\"3\n\x1b\x43MsgClientAMGetClanOfficers\x12\x14\n\x0csteamid_clan\x18\x01 \x01(\x06\"f\n#CMsgClientAMGetClanOfficersResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x14\n\x0csteamid_clan\x18\x02 \x01(\x06\x12\x15\n\rofficer_count\x18\x03 \x01(\x05\"\x90\x01\n!CMsgClientAMGetPersonaNameHistory\x12\x10\n\x08id_count\x18\x01 \x01(\x05\x12:\n\x03Ids\x18\x02 \x03(\x0b\x32-.CMsgClientAMGetPersonaNameHistory.IdInstance\x1a\x1d\n\nIdInstance\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"\xc3\x02\n)CMsgClientAMGetPersonaNameHistoryResponse\x12O\n\tresponses\x18\x02 \x03(\x0b\x32<.CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance\x1a\xc4\x01\n\x11NameTableInstance\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12X\n\x05names\x18\x03 \x03(\x0b\x32I.CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance.NameInstance\x1a\x30\n\x0cNameInstance\x12\x12\n\nname_since\x18\x01 \x01(\x07\x12\x0c\n\x04name\x18\x02 \x01(\t\"E\n\x1e\x43MsgClientDeregisterWithServer\x12\x13\n\x0b\x65servertype\x18\x01 \x01(\r\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\"\xab\x04\n\x13\x43MsgClientClanState\x12\x14\n\x0csteamid_clan\x18\x01 \x01(\x06\x12\x1a\n\x12\x63lan_account_flags\x18\x03 \x01(\r\x12\x30\n\tname_info\x18\x04 \x01(\x0b\x32\x1d.CMsgClientClanState.NameInfo\x12\x34\n\x0buser_counts\x18\x05 \x01(\x0b\x32\x1f.CMsgClientClanState.UserCounts\x12*\n\x06\x65vents\x18\x06 \x03(\x0b\x32\x1a.CMsgClientClanState.Event\x12\x31\n\rannouncements\x18\x07 \x03(\x0b\x32\x1a.CMsgClientClanState.Event\x12\x19\n\x11\x63hat_room_private\x18\x08 \x01(\x08\x1a\x31\n\x08NameInfo\x12\x11\n\tclan_name\x18\x01 \x01(\t\x12\x12\n\nsha_avatar\x18\x02 \x01(\x0c\x1ak\n\nUserCounts\x12\x0f\n\x07members\x18\x01 \x01(\r\x12\x0e\n\x06online\x18\x02 \x01(\r\x12\x10\n\x08\x63hatting\x18\x03 \x01(\r\x12\x0f\n\x07in_game\x18\x04 \x01(\r\x12\x19\n\x11\x63hat_room_members\x18\x05 \x01(\r\x1a`\n\x05\x45vent\x12\x0b\n\x03gid\x18\x01 \x01(\x06\x12\x12\n\nevent_time\x18\x02 \x01(\r\x12\x10\n\x08headline\x18\x03 \x01(\t\x12\x0f\n\x07game_id\x18\x04 \x01(\x06\x12\x13\n\x0bjust_posted\x18\x05 \x01(\x08\x42\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_clientserver_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _CMSGCLIENTWALLETINFOUPDATE.fields_by_name['balance64']._options = None
  _CMSGCLIENTWALLETINFOUPDATE.fields_by_name['balance64']._serialized_options = b'\240\266\030\001'
  _CMSGCLIENTWALLETINFOUPDATE.fields_by_name['balance64_delayed']._options = None
  _CMSGCLIENTWALLETINFOUPDATE.fields_by_name['balance64_delayed']._serialized_options = b'\240\266\030\001'
  _CMSGCLIENTREGISTERAUTHTICKETWITHCM._serialized_start=90
  _CMSGCLIENTREGISTERAUTHTICKETWITHCM._serialized_end=196
  _CMSGCLIENTTICKETAUTHCOMPLETE._serialized_start=199
  _CMSGCLIENTTICKETAUTHCOMPLETE._serialized_end=408
  _CMSGCLIENTP2PCONNECTIONINFO._serialized_start=411
  _CMSGCLIENTP2PCONNECTIONINFO._serialized_end=574
  _CMSGCLIENTP2PCONNECTIONFAILINFO._serialized_start=577
  _CMSGCLIENTP2PCONNECTIONFAILINFO._serialized_end=772
  _CMSGCLIENTNETWORKINGCERTREQUEST._serialized_start=774
  _CMSGCLIENTNETWORKINGCERTREQUEST._serialized_end=841
  _CMSGCLIENTNETWORKINGCERTREPLY._serialized_start=843
  _CMSGCLIENTNETWORKINGCERTREPLY._serialized_end=929
  _CMSGCLIENTNETWORKINGMOBILECERTREQUEST._serialized_start=931
  _CMSGCLIENTNETWORKINGMOBILECERTREQUEST._serialized_end=986
  _CMSGCLIENTNETWORKINGMOBILECERTREPLY._serialized_start=988
  _CMSGCLIENTNETWORKINGMOBILECERTREPLY._serialized_end=1047
  _CMSGCLIENTGETAPPOWNERSHIPTICKET._serialized_start=1049
  _CMSGCLIENTGETAPPOWNERSHIPTICKET._serialized_end=1098
  _CMSGCLIENTGETAPPOWNERSHIPTICKETRESPONSE._serialized_start=1100
  _CMSGCLIENTGETAPPOWNERSHIPTICKETRESPONSE._serialized_end=1193
  _CMSGCLIENTSESSIONTOKEN._serialized_start=1195
  _CMSGCLIENTSESSIONTOKEN._serialized_end=1234
  _CMSGCLIENTGAMECONNECTTOKENS._serialized_start=1236
  _CMSGCLIENTGAMECONNECTTOKENS._serialized_end=1313
  _CMSGCLIENTGAMESPLAYED._serialized_start=1316
  _CMSGCLIENTGAMESPLAYED._serialized_end=2493
  _CMSGCLIENTGAMESPLAYED_PROCESSINFO._serialized_start=1486
  _CMSGCLIENTGAMESPLAYED_PROCESSINFO._serialized_end=1571
  _CMSGCLIENTGAMESPLAYED_GAMEPLAYED._serialized_start=1574
  _CMSGCLIENTGAMESPLAYED_GAMEPLAYED._serialized_end=2493
  _CMSGGSAPPROVE._serialized_start=2495
  _CMSGGSAPPROVE._serialized_end=2552
  _CMSGGSDENY._serialized_start=2554
  _CMSGGSDENY._serialized_end=2627
  _CMSGGSKICK._serialized_start=2629
  _CMSGGSKICK._serialized_end=2681
  _CMSGCLIENTAUTHLIST._serialized_start=2684
  _CMSGCLIENTAUTHLIST._serialized_end=2884
  _CMSGCLIENTAUTHLISTACK._serialized_start=2886
  _CMSGCLIENTAUTHLISTACK._serialized_end=2972
  _CMSGCLIENTLICENSELIST._serialized_start=2975
  _CMSGCLIENTLICENSELIST._serialized_end=3501
  _CMSGCLIENTLICENSELIST_LICENSE._serialized_start=3071
  _CMSGCLIENTLICENSELIST_LICENSE._serialized_end=3501
  _CMSGCLIENTISLIMITEDACCOUNT._serialized_start=3504
  _CMSGCLIENTISLIMITEDACCOUNT._serialized_end=3674
  _CMSGCLIENTREQUESTEDCLIENTSTATS._serialized_start=3677
  _CMSGCLIENTREQUESTEDCLIENTSTATS._serialized_end=3844
  _CMSGCLIENTREQUESTEDCLIENTSTATS_STATSTOSEND._serialized_start=3779
  _CMSGCLIENTREQUESTEDCLIENTSTATS_STATSTOSEND._serialized_end=3844
  _CMSGCLIENTSTAT2._serialized_start=3847
  _CMSGCLIENTSTAT2._serialized_end=4039
  _CMSGCLIENTSTAT2_STATDETAIL._serialized_start=3916
  _CMSGCLIENTSTAT2_STATDETAIL._serialized_end=4039
  _CMSGCLIENTINVITETOGAME._serialized_start=4041
  _CMSGCLIENTINVITETOGAME._serialized_end=4155
  _CMSGCLIENTCHATINVITE._serialized_start=4158
  _CMSGCLIENTCHATINVITE._serialized_end=4343
  _CMSGCLIENTCONNECTIONSTATS._serialized_start=4346
  _CMSGCLIENTCONNECTIONSTATS._serialized_end=5491
  _CMSGCLIENTCONNECTIONSTATS_STATS_LOGON._serialized_start=4498
  _CMSGCLIENTCONNECTIONSTATS_STATS_LOGON._serialized_end=4837
  _CMSGCLIENTCONNECTIONSTATS_STATS_UDP._serialized_start=4839
  _CMSGCLIENTCONNECTIONSTATS_STATS_UDP._serialized_end=4952
  _CMSGCLIENTCONNECTIONSTATS_STATS_VCONN._serialized_start=4955
  _CMSGCLIENTCONNECTIONSTATS_STATS_VCONN._serialized_end=5491
  _CMSGCLIENTSERVERSAVAILABLE._serialized_start=5494
  _CMSGCLIENTSERVERSAVAILABLE._serialized_end=5704
  _CMSGCLIENTSERVERSAVAILABLE_SERVER_TYPES_AVAILABLE._serialized_start=5647
  _CMSGCLIENTSERVERSAVAILABLE_SERVER_TYPES_AVAILABLE._serialized_end=5704
  _CMSGCLIENTREPORTOVERLAYDETOURFAILURE._serialized_start=5706
  _CMSGCLIENTREPORTOVERLAYDETOURFAILURE._serialized_end=5769
  _CMSGCLIENTREQUESTENCRYPTEDAPPTICKET._serialized_start=5771
  _CMSGCLIENTREQUESTENCRYPTEDAPPTICKET._serialized_end=5842
  _CMSGCLIENTREQUESTENCRYPTEDAPPTICKETRESPONSE._serialized_start=5845
  _CMSGCLIENTREQUESTENCRYPTEDAPPTICKETRESPONSE._serialized_end=5977
  _CMSGCLIENTWALLETINFOUPDATE._serialized_start=5980
  _CMSGCLIENTWALLETINFOUPDATE._serialized_end=6161
  _CMSGCLIENTAMGETCLANOFFICERS._serialized_start=6163
  _CMSGCLIENTAMGETCLANOFFICERS._serialized_end=6214
  _CMSGCLIENTAMGETCLANOFFICERSRESPONSE._serialized_start=6216
  _CMSGCLIENTAMGETCLANOFFICERSRESPONSE._serialized_end=6318
  _CMSGCLIENTAMGETPERSONANAMEHISTORY._serialized_start=6321
  _CMSGCLIENTAMGETPERSONANAMEHISTORY._serialized_end=6465
  _CMSGCLIENTAMGETPERSONANAMEHISTORY_IDINSTANCE._serialized_start=6436
  _CMSGCLIENTAMGETPERSONANAMEHISTORY_IDINSTANCE._serialized_end=6465
  _CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE._serialized_start=6468
  _CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE._serialized_end=6791
  _CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE._serialized_start=6595
  _CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE._serialized_end=6791
  _CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE_NAMEINSTANCE._serialized_start=6743
  _CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE_NAMEINSTANCE._serialized_end=6791
  _CMSGCLIENTDEREGISTERWITHSERVER._serialized_start=6793
  _CMSGCLIENTDEREGISTERWITHSERVER._serialized_end=6862
  _CMSGCLIENTCLANSTATE._serialized_start=6865
  _CMSGCLIENTCLANSTATE._serialized_end=7420
  _CMSGCLIENTCLANSTATE_NAMEINFO._serialized_start=7164
  _CMSGCLIENTCLANSTATE_NAMEINFO._serialized_end=7213
  _CMSGCLIENTCLANSTATE_USERCOUNTS._serialized_start=7215
  _CMSGCLIENTCLANSTATE_USERCOUNTS._serialized_end=7322
  _CMSGCLIENTCLANSTATE_EVENT._serialized_start=7324
  _CMSGCLIENTCLANSTATE_EVENT._serialized_end=7420
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver_userstats.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*steammessages_clientserver_userstats.proto\x1a\x18steammessages_base.proto\"u\n\x16\x43MsgClientGetUserStats\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\x12\x11\n\tcrc_stats\x18\x02 \x01(\r\x12\x1c\n\x14schema_local_version\x18\x03 \x01(\x05\x12\x19\n\x11steam_id_for_user\x18\x04 \x01(\x06\"\xdf\x02\n\x1e\x43MsgClientGetUserStatsResponse\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\x12\x12\n\x07\x65result\x18\x02 \x01(\x05:\x01\x32\x12\x11\n\tcrc_stats\x18\x03 \x01(\r\x12\x0e\n\x06schema\x18\x04 \x01(\x0c\x12\x34\n\x05stats\x18\x05 \x03(\x0b\x32%.CMsgClientGetUserStatsResponse.Stats\x12N\n\x12\x61\x63hievement_blocks\x18\x06 \x03(\x0b\x32\x32.CMsgClientGetUserStatsResponse.Achievement_Blocks\x1a,\n\x05Stats\x12\x0f\n\x07stat_id\x18\x01 \x01(\r\x12\x12\n\nstat_value\x18\x02 \x01(\r\x1a\x41\n\x12\x41\x63hievement_Blocks\x12\x16\n\x0e\x61\x63hievement_id\x18\x01 \x01(\r\x12\x13\n\x0bunlock_time\x18\x02 \x03(\x07\"\x9a\x02\n CMsgClientStoreUserStatsResponse\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\x12\x12\n\x07\x65result\x18\x02 \x01(\x05:\x01\x32\x12\x11\n\tcrc_stats\x18\x03 \x01(\r\x12Z\n\x17stats_failed_validation\x18\x04 \x03(\x0b\x32\x39.CMsgClientStoreUserStatsResponse.Stats_Failed_Validation\x12\x19\n\x11stats_out_of_date\x18\x05 \x01(\x08\x1aG\n\x17Stats_Failed_Validation\x12\x0f\n\x07stat_id\x18\x01 \x01(\r\x12\x1b\n\x13reverted_stat_value\x18\x02 \x01(\r\"\xe8\x01\n\x19\x43MsgClientStoreUserStats2\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\x12\x17\n\x0fsettor_steam_id\x18\x02 \x01(\x06\x12\x17\n\x0fsettee_steam_id\x18\x03 \x01(\x06\x12\x11\n\tcrc_stats\x18\x04 \x01(\r\x12\x16\n\x0e\x65xplicit_reset\x18\x05 \x01(\x08\x12/\n\x05stats\x18\x06 \x03(\x0b\x32 .CMsgClientStoreUserStats2.Stats\x1a,\n\x05Stats\x12\x0f\n\x07stat_id\x18\x01 \x01(\r\x12\x12\n\nstat_value\x18\x02 \x01(\r\"\xc2\x01\n\x16\x43MsgClientStatsUpdated\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x0f\n\x07game_id\x18\x02 \x01(\x06\x12\x11\n\tcrc_stats\x18\x03 \x01(\r\x12<\n\rupdated_stats\x18\x04 \x03(\x0b\x32%.CMsgClientStatsUpdated.Updated_Stats\x1a\x34\n\rUpdated_Stats\x12\x0f\n\x07stat_id\x18\x01 \x01(\r\x12\x12\n\nstat_value\x18\x02 \x01(\r\"\xbc\x01\n\x18\x43MsgClientStoreUserStats\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\x12\x16\n\x0e\x65xplicit_reset\x18\x02 \x01(\x08\x12@\n\x0estats_to_store\x18\x03 \x03(\x0b\x32(.CMsgClientStoreUserStats.Stats_To_Store\x1a\x35\n\x0eStats_To_Store\x12\x0f\n\x07stat_id\x18\x01 \x01(\r\x12\x12\n\nstat_value\x18\x02 \x01(\rB\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_clientserver_userstats_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _CMSGCLIENTGETUSERSTATS._serialized_start=72
  _CMSGCLIENTGETUSERSTATS._serialized_end=189
  _CMSGCLIENTGETUSERSTATSRESPONSE._serialized_start=192
  _CMSGCLIENTGETUSERSTATSRESPONSE._serialized_end=543
  _CMSGCLIENTGETUSERSTATSRESPONSE_STATS._serialized_start=432
  _CMSGCLIENTGETUSERSTATSRESPONSE_STATS._serialized_end=476
  _CMSGCLIENTGETUSERSTATSRESPONSE_ACHIEVEMENT_BLOCKS._serialized_start=478
  _CMSGCLIENTGETUSERSTATSRESPONSE_ACHIEVEMENT_BLOCKS._serialized_end=543
  _CMSGCLIENTSTOREUSERSTATSRESPONSE._serialized_start=546
  _CMSGCLIENTSTOREUSERSTATSRESPONSE._serialized_end=828
  _CMSGCLIENTSTOREUSERSTATSRESPONSE_STATS_FAILED_VALIDATION._serialized_start=757
  _CMSGCLIENTSTOREUSERSTATSRESPONSE_STATS_FAILED_VALIDATION._serialized_end=828
  _CMSGCLIENTSTOREUSERSTATS2._serialized_start=831
  _CMSGCLIENTSTOREUSERSTATS2._serialized_end=1063
  _CMSGCLIENTSTOREUSERSTATS2_STATS._serialized_start=432
  _CMSGCLIENTSTOREUSERSTATS2_STATS._serialized_end=476
  _CMSGCLIENTSTATSUPDATED._serialized_start=1066
  _CMSGCLIENTSTATSUPDATED._serialized_end=1260
  _CMSGCLIENTSTATSUPDATED_UPDATED_STATS._serialized_start=1208
  _CMSGCLIENTSTATSUPDATED_UPDATED_STATS._serialized_end=1260
  _CMSGCLIENTSTOREUSERSTATS._serialized_start=1263
  _CMSGCLIENTSTOREUSERSTATS._serialized_end=1451
  _CMSGCLIENTSTOREUSERSTATS_STATS_TO_STORE._serialized_start=1398
  _CMSGCLIENTSTOREUSERSTATS_STATS_TO_STORE._serialized_end=1451
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steamnetworkingsockets_messages_certs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+steamnetworkingsockets_messages_certs.proto\"\x81\x01\n\'CMsgSteamNetworkingIdentityLegacyBinary\x12\x10\n\x08steam_id\x18\x10 \x01(\x06\x12\x15\n\rgeneric_bytes\x18\x02 \x01(\x0c\x12\x16\n\x0egeneric_string\x18\x03 \x01(\t\x12\x15\n\ripv6_and_port\x18\x04 \x01(\x0c\"\x8a\x03\n\x1c\x43MsgSteamDatagramCertificate\x12\x41\n\x08key_type\x18\x01 \x01(\x0e\x32&.CMsgSteamDatagramCertificate.EKeyType:\x07INVALID\x12\x10\n\x08key_data\x18\x02 \x01(\x0c\x12\x17\n\x0flegacy_steam_id\x18\x04 \x01(\x06\x12H\n\x16legacy_identity_binary\x18\x0b \x01(\x0b\x32(.CMsgSteamNetworkingIdentityLegacyBinary\x12\x17\n\x0fidentity_string\x18\x0c \x01(\t\x12!\n\x19gameserver_datacenter_ids\x18\x05 \x03(\x07\x12\x14\n\x0ctime_created\x18\x08 \x01(\x07\x12\x13\n\x0btime_expiry\x18\t \x01(\x07\x12\x0f\n\x07\x61pp_ids\x18\n \x03(\r\x12\x14\n\x0cip_addresses\x18\r \x03(\t\"$\n\x08\x45KeyType\x12\x0b\n\x07INVALID\x10\x00\x12\x0b\n\x07\x45\x44\x32\x35\x35\x31\x39\x10\x01\"u\n\"CMsgSteamDatagramCertificateSigned\x12\x0c\n\x04\x63\x65rt\x18\x04 \x01(\x0c\x12\x11\n\tca_key_id\x18\x05 \x01(\x06\x12\x14\n\x0c\x63\x61_signature\x18\x06 \x01(\x0c\x12\x18\n\x10private_key_data\x18\x01 \x01(\x0c\"R\n#CMsgSteamDatagramCertificateRequest\x12+\n\x04\x63\x65rt\x18\x01 \x01(\x0b\x32\x1d.CMsgSteamDatagramCertificateB\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steamnetworkingsockets_messages_certs_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _CMSGSTEAMNETWORKINGIDENTITYLEGACYBINARY._serialized_start=48
  _CMSGSTEAMNETWORKINGIDENTITYLEGACYBINARY._serialized_end=177
  _CMSGSTEAMDATAGRAMCERTIFICATE._serialized_start=180
  _CMSGSTEAMDATAGRAMCERTIFICATE._serialized_end=574
  _CMSGSTEAMDATAGRAMCERTIFICATE_EKEYTYPE._serialized_start=538
  _CMSGSTEAMDATAGRAMCERTIFICATE_EKEYTYPE._serialized_end=574
  _CMSGSTEAMDATAGRAMCERTIFICATESIGNED._serialized_start=576
  _CMSGSTEAMDATAGRAMCERTIFICATESIGNED._serialized_end=693
  _CMSGSTEAMDATAGRAMCERTIFICATEREQUEST._serialized_start=695
  _CMSGSTEAMDATAGRAMCERTIFICATEREQUEST._serialized_end=777
# @@protoc_insertion_point(module_scope)
